@@ -1,4 +1,4 @@
-from bolinette.console import console
+from bolinette.console import Console, console
 from bolinette.bcrypt import bcrypt
 import bolinette.defaults
 import bolinette.init
