@@ -1,7 +1,6 @@
 from typing import List, Callable, Dict, Type
 
 from bolinette import blnt, core, web
-from bolinette.testing import Bolitest
 
 
 class BolinetteCache:
@@ -13,7 +12,6 @@ class BolinetteCache:
         self.middlewares: Dict[str, Type['web.Middleware']] = {}
         self.topics: Dict[str, Type['web.Topic']] = {}
         self.init_funcs: List[Callable[['blnt.BolinetteContext'], None]] = []
-        self.test_funcs: List[Bolitest] = []
         self.seeders = []
 
 
