@@ -1,12 +1,14 @@
 import inspect
-from typing import Type, Callable, List, Union
+from typing import Type, Callable, List, Union, Literal
 
 from bolinette import blnt, core, web
 
 
-def model(model_name: str, database: str = 'default'):
+def model(model_name: str, *, database: str = 'default',
+          model_type: Literal['relational', 'collection'] = 'relational',
+          join_table: bool = False):
     def decorator(model_cls: Type['core.Model']):
-        model_cls.__blnt__ = core.ModelMetadata(model_name, database)
+        model_cls.__blnt__ = core.ModelMetadata(model_name, database, model_type == 'relational', join_table)
         blnt.cache.models[model_name] = model_cls
         return model_cls
     return decorator
@@ -26,6 +28,7 @@ def mixin(mixin_name: str):
 def with_mixin(mixin_name: str):
     def decorator(model_cls):
         mixin_cls = blnt.cache.mixins.get(mixin_name)
+        model_cls.__mixins__[mixin_name] = mixin_cls
         for col_name, col_def in mixin_cls.columns().items():
             setattr(model_cls, col_name, col_def)
         for rel_name, rel_def in mixin_cls.relationships(model_cls).items():
@@ -39,6 +42,11 @@ def init_func(func: Callable[['blnt.BolinetteContext'], None]):
     return func
 
 
+def with_context(func: Callable[['blnt.BolinetteContext'], None]):
+    blnt.cache.with_ctx_funcs.append(func)
+    return func
+
+
 def seeder(func):
     blnt.cache.seeders.append(func)
     return func
@@ -96,9 +104,9 @@ def route(path: str, *, method: web.HttpMethod, expects: 'web.Expects' = None, r
     return decorator
 
 
-def get(path: str, *, expects: 'web.Expects' = None, returns: 'web.Returns' = None,
+def get(path: str, *, returns: 'web.Returns' = None,
         middlewares: Union[str, List[str]] = None):
-    return route(path, method=web.HttpMethod.GET, expects=expects, returns=returns, middlewares=middlewares)
+    return route(path, method=web.HttpMethod.GET, expects=None, returns=returns, middlewares=middlewares)
 
 
 def post(path: str, *, expects: 'web.Expects' = None, returns: 'web.Returns' = None,
@@ -116,12 +124,12 @@ def patch(path: str, *, expects: 'web.Expects' = None, returns: 'web.Returns' =
     return route(path, method=web.HttpMethod.PATCH, expects=expects, returns=returns, middlewares=middlewares)
 
 
-def delete(path: str, *, expects: 'web.Expects' = None, returns: 'web.Returns' = None,
+def delete(path: str, *, returns: 'web.Returns' = None,
            middlewares: Union[str, List[str]] = None):
-    return route(path, method=web.HttpMethod.DELETE, expects=expects, returns=returns, middlewares=middlewares)
+    return route(path, method=web.HttpMethod.DELETE, expects=None, returns=returns, middlewares=middlewares)
 
 
-def middleware(name: str, *, priority: int = 10, auto_load: bool = False, loadable: bool = True):
+def middleware(name: str, *, priority: int = 100, auto_load: bool = False, loadable: bool = True):
     def decorator(middleware_cls: Type['web.Middleware']):
         middleware_cls.__blnt__ = web.MiddlewareMetadata(name, priority, auto_load, loadable)
         blnt.cache.middlewares[name] = middleware_cls
