@@ -1,7 +1,7 @@
 import sqlalchemy
 from sqlalchemy import orm as sqlalchemy_orm
 
-from bolinette import blnt, core, web
+from bolinette import blnt, core
 from bolinette.decorators import init_func
 from bolinette.exceptions import InitError
 
@@ -22,13 +22,13 @@ def init_relational_models(context: blnt.BolinetteContext):
     orm_cols = {}
     for model_name, model in models.items():
         orm_cols[model_name] = {}
-        for att_name, attribute in model.__props__.get_columns().items():
+        for att_name, attribute in model.__props__.get_columns():
             attribute.name = att_name
             ref = None
             if attribute.reference:
                 ref = sqlalchemy.ForeignKey(f'{attribute.reference.model_name}.{attribute.reference.column_name}')
             orm_cols[model_name][att_name] = sqlalchemy.Column(
-                att_name, attribute.type.sqlalchemy_type, ref, default=attribute.default,
+                att_name, attribute.type.sqlalchemy_type, ref, default=attribute.default, index=attribute.model_id,
                 primary_key=attribute.primary_key, nullable=attribute.nullable, unique=attribute.unique)
         orm_tables[model_name] = sqlalchemy.Table(model_name,
                                                   model.__props__.database.base.metadata,
@@ -36,7 +36,7 @@ def init_relational_models(context: blnt.BolinetteContext):
 
     for model_name, model in models.items():
         orm_defs = {}
-        for att_name, attribute in model.__props__.get_relationships().items():
+        for att_name, attribute in model.__props__.get_relationships():
             kwargs = {}
             attribute.name = att_name
             if attribute.backref:
@@ -52,7 +52,7 @@ def init_relational_models(context: blnt.BolinetteContext):
         orm_defs['__table__'] = orm_tables[model_name]
         orm_model = type(model_name, (model.__props__.database.base,), orm_defs)
 
-        for att_name, attribute in model.__props__.get_properties().items():
+        for att_name, attribute in model.__props__.get_properties():
             setattr(orm_model, att_name, property(attribute.function))
 
         context.add_model(model_name, model)
@@ -72,7 +72,7 @@ def init_collection_models(context: blnt.BolinetteContext):
             raise InitError(f'Undefined "{db_key}" database for model "{model_name}"')
         models[model_name] = model_cls(database)
     for model_name, model in models.items():
-        for att_name, attribute in model.__props__.get_columns().items():
+        for att_name, attribute in model.__props__.get_columns():
             attribute.name = att_name
         context.add_model(model_name, model)
 
@@ -105,8 +105,10 @@ def init_controllers(context: blnt.BolinetteContext):
     for controller_name, controller_cls in blnt.cache.controllers.items():
         controller = controller_cls(context)
         for _, route in controller.__props__.get_routes():
+            route.controller = controller
             route.setup(controller)
         for route in controller.default_routes():
+            route.controller = controller
             route.setup(controller)
         context.add_controller(controller_name, controller)
 
