@@ -13,7 +13,7 @@ class Controller:
     def __init__(self, context: 'blnt.BolinetteContext'):
         self.__props__ = ControllerProps(self)
         self.context = context
-        self.response = context.response
+        self.response = web.Response(context)
         if self.__blnt__.use_service:
             self.defaults = ControllerDefaults(self)
 
@@ -84,6 +84,7 @@ class ControllerRoute:
             self.inner_route.setup(controller)
 
     def _init_middlewares(self, context: 'blnt.BolinetteContext', from_controller: List[str], system: List[str]):
+        self.middlewares = []
         for mdw in system:
             self._parse_middleware_options(mdw, context, True)
         for mdw in from_controller:
@@ -133,50 +134,30 @@ class ControllerRoute:
             raise InitError(f'[{self.controller.__class__.__name__}] Middleware '
                             f'"{mdw}" cannot be loaded in a controller')
 
+        parsed_args = {}
         for arg in args:
             arg_n, *arg_v = arg.split('=', maxsplit=1)
-            arg_n, *filters = arg_n.split(':')
-            if len(filters) > 1:
-                raise InitError(f'[{self.controller.__class__.__name__}] Middleware '
-                                f'"{name}|{arg_n}" has too many filters')
-            if len(arg_v) == 0:
-                value = True
+            parsed_args[arg_n] = arg_v[0] if len(arg_v) else True
+        def_options = middleware.define_options()
+        for opt_name, option in def_options.items():
+            if opt_name in parsed_args:
+                middleware.options[opt_name] = option.validate(parsed_args[opt_name])
+            elif option.required:
+                raise InitError(f'[{self.controller.__class__.__name__}] Middleware "{mdw}" '
+                                f'option "{opt_name}" is missing from declaration string')
             else:
-                value = arg_v[0].split(',')
-                if len(value) == 1:
-                    value = value[0]
-                if len(filters) == 1:
-                    value = self._apply_filters(value, filters[0], name, arg_n)
-            middleware.options[arg_n] = value
+                middleware.options[opt_name] = option.default
         self.middlewares.append(middleware)
 
-    def _apply_filters(self, value, _filter, mdw, arg):
-        if _filter == 'int':
-            func = int
-        elif _filter == 'float':
-            func = float
-        else:
-            raise InitError(f'[{self.controller.__class__.__name__}] middleware '
-                            f'"{mdw}|{arg}": unknown filter "{_filter}"')
-        try:
-            if isinstance(value, list):
-                return [func(v) for v in value]
-            return func(value)
-        except ValueError:
-            raise InitError(f'[{self.controller.__class__.__name__}] middleware '
-                            f'"{mdw}|{arg}": unable to parse "{value}" as {_filter}')
-
-    async def call_middleware_chain(self, request: Request, params: Dict[str, Any], track: 'MiddlewareTrack'):
+    async def call_middleware_chain(self, request: Request, params: Dict[str, Any]):
         handles = ([MiddlewareHandle(name=m.__blnt__.name, func=m.handle) for m in self.middlewares]
                    + [MiddlewareHandle('__ctrl_call', self._final_middleware_call)])
-        return await self._call_middleware(handles, 0, request, params, track)
+        return await self._call_middleware(handles, 0, request, params)
 
     async def _call_middleware(self, handles: List['MiddlewareHandle'], index: int, request: Request,
-                               params: Dict[str, Any], track: 'MiddlewareTrack'):
+                               params: Dict[str, Any]):
         async def _next(_request, _params):
-            return await self._call_middleware(handles, index + 1, _request, _params, track)
-        track.append(handles[index].name)
-        track.done = handles[index].name == '__ctrl_call'
+            return await self._call_middleware(handles, index + 1, _request, _params)
         return await handles[index].func(request, params, _next)
 
     async def _final_middleware_call(self, _1, params: Dict[str, Any], _2):
@@ -189,15 +170,6 @@ class MiddlewareHandle:
         self.func = func
 
 
-class MiddlewareTrack:
-    def __init__(self):
-        self.done = False
-        self.steps: List[str] = []
-
-    def append(self, step: str):
-        self.steps.append(step)
-
-
 class Expects:
     def __init__(self, model: str, key: str = 'default', *, patch: bool = False):
         self.model = model
@@ -217,10 +189,11 @@ class ControllerDefaults:
     def __init__(self, controller: Controller):
         self.service: core.Service = controller.service
 
-    def get_all(self, returns='default', *, middlewares: List[str] = None, docstring: str = None):
-        async def route(controller, **kwargs):
+    def get_all(self, returns='default', *, prefix='',
+                middlewares: List[str] = None, docstring: str = None):
+        async def route(controller: web.Controller, **kwargs):
             resp = await functions.async_invoke(controller.service.get_all, **kwargs)
-            return controller.response.ok('OK', resp)
+            return controller.response.ok(data=resp)
 
         model_name = self.service.__blnt__.model_name
         docstring = docstring or f"""
@@ -228,29 +201,32 @@ class ControllerDefaults:
 
         -response 200 returns: The list of {model_name} entities
         """
-        return ControllerRoute(route, '', web.HttpMethod.GET, docstring,
+        return ControllerRoute(route, f'{prefix}', web.HttpMethod.GET, docstring,
                                returns=Returns(model_name, returns, as_list=True),
                                middlewares=middlewares)
 
-    def get_one(self, returns='default', *, key='id', middlewares: List[str] = None, docstring: str = None):
-        async def route(controller, *, match, **kwargs):
+    def get_one(self, returns='default', *, key: str = None, prefix='',
+                middlewares: List[str] = None, docstring: str = None):
+        async def route(controller: web.Controller, *, match, **kwargs):
             resp = await functions.async_invoke(controller.service.get_first_by, key, match.get(key), **kwargs)
-            return controller.response.ok('OK', resp)
+            return controller.response.ok(data=resp)
 
         model_name = self.service.__blnt__.model_name
+        key = key or self.service.repo.model.__props__.model_id.name
         docstring = docstring or f"""
         Gets one record from {model_name} collection, identified by {key} field
 
         -response 200 returns: The {model_name} entity
         """
-        return ControllerRoute(route, f'/{{{key}}}', web.HttpMethod.GET, docstring,
+        return ControllerRoute(route, f'{prefix}/{{{key}}}', web.HttpMethod.GET, docstring,
                                returns=Returns(model_name, returns),
                                middlewares=middlewares)
 
-    def create(self, returns='default', expects='default', *, middlewares: List[str] = None, docstring: str = None):
-        async def route(controller, payload, **kwargs):
+    def create(self, returns='default', expects='default', *, prefix='',
+               middlewares: List[str] = None, docstring: str = None):
+        async def route(controller: web.Controller, payload, **kwargs):
             resp = await functions.async_invoke(controller.service.create, payload, **kwargs)
-            return controller.response.created(f'{controller.service.__blnt__.model_name}.created', resp)
+            return controller.response.created(messages=f'{controller.service.__blnt__.model_name}.created', data=resp)
 
         model_name = self.service.__blnt__.model_name
         docstring = docstring or f"""
@@ -258,59 +234,63 @@ class ControllerDefaults:
 
         -response 201 returns: The created {model_name} entity
         """
-        return ControllerRoute(route, '', web.HttpMethod.POST, docstring,
+        return ControllerRoute(route, f'{prefix}', web.HttpMethod.POST, docstring,
                                expects=Expects(self.service.__blnt__.model_name, expects),
                                returns=Returns(model_name, returns),
                                middlewares=middlewares)
 
-    def update(self, returns='default', expects='default', *, key='id',
+    def update(self, returns='default', expects='default', *, key: str = None, prefix='',
                middlewares: List[str] = None, docstring: str = None):
-        async def route(controller, payload, match, **kwargs):
+        async def route(controller: web.Controller, payload, match, **kwargs):
             entity = await controller.service.get_first_by(key, match.get(key))
             resp = await functions.async_invoke(controller.service.update, entity, payload, **kwargs)
-            return controller.response.ok(f'{controller.service.__blnt__.model_name}.updated', resp)
+            return controller.response.ok(messages=f'{controller.service.__blnt__.model_name}.updated', data=resp)
 
         model_name = self.service.__blnt__.model_name
+        key = key or self.service.repo.model.__props__.model_id.name
         docstring = docstring or f"""
         Updates all fields from one {model_name} entity, identified by {key} field
 
         -response 200 returns: The updated {model_name} entity
         """
-        return ControllerRoute(route, f'/{{{key}}}', web.HttpMethod.PUT, docstring,
+        return ControllerRoute(route, f'{prefix}/{{{key}}}', web.HttpMethod.PUT, docstring,
                                expects=Expects(self.service.__blnt__.model_name, expects),
                                returns=Returns(model_name, returns),
                                middlewares=middlewares)
 
-    def patch(self, returns='default', expects='default', *, key='id',
+    def patch(self, returns='default', expects='default', *, key: str = None, prefix='',
               middlewares: List[str] = None, docstring: str = None):
-        async def route(controller, payload, match, **kwargs):
+        async def route(controller: web.Controller, payload, match, **kwargs):
             entity = await controller.service.get_first_by(key, match.get(key))
             resp = await functions.async_invoke(controller.service.patch, entity, payload, **kwargs)
-            return controller.response.ok(f'{controller.service.__blnt__.model_name}.updated', resp)
+            return controller.response.ok(messages=f'{controller.service.__blnt__.model_name}.updated', data=resp)
 
         model_name = self.service.__blnt__.model_name
+        key = key or self.service.repo.model.__props__.model_id.name
         docstring = docstring or f"""
         Updates some fields from one {model_name} entity, identified by {key} field
 
         -response 200 returns: The updated {model_name} entity
         """
-        return ControllerRoute(route, f'/{{{key}}}', web.HttpMethod.PATCH, docstring,
+        return ControllerRoute(route, f'{prefix}/{{{key}}}', web.HttpMethod.PATCH, docstring,
                                expects=Expects(self.service.__blnt__.model_name, expects, patch=True),
                                returns=Returns(model_name, returns),
                                middlewares=middlewares)
 
-    def delete(self, returns='default', *, key='id', middlewares: List[str] = None, docstring: str = None):
-        async def route(controller, match, **kwargs):
+    def delete(self, returns='default', *, key: str = None, prefix='',
+               middlewares: List[str] = None, docstring: str = None):
+        async def route(controller: web.Controller, match, **kwargs):
             entity = await controller.service.get_first_by(key, match.get(key))
             resp = await functions.async_invoke(controller.service.delete, entity, **kwargs)
-            return controller.response.ok(f'{controller.service.__blnt__.model_name}.deleted', resp)
+            return controller.response.ok(messages=f'{controller.service.__blnt__.model_name}.deleted', data=resp)
 
         model_name = self.service.__blnt__.model_name
+        key = key or self.service.repo.model.__props__.model_id.name
         docstring = docstring or f"""
         Deletes on record from {model_name} collection, identified by {key} field
 
         -response 200 returns: The deleted {model_name} entity
         """
-        return ControllerRoute(route, f'/{{{key}}}', web.HttpMethod.DELETE, docstring,
+        return ControllerRoute(route, f'{prefix}/{{{key}}}', web.HttpMethod.DELETE, docstring,
                                returns=Returns(model_name, returns),
                                middlewares=middlewares)
