@@ -1,5 +1,5 @@
 from os import PathLike
-from typing import Union
+from typing import Union, List
 
 from aiohttp.web_response import Response as AioResponse
 from jinja2 import TemplateNotFound
@@ -39,7 +39,8 @@ class Response:
         }
         self.context = context
 
-    def build_message(self, code, status, messages=None, data=None):
+    @staticmethod
+    def _build_message(code, status, messages=None, data=None):
         if messages is None:
             messages = []
         if not isinstance(messages, list):
@@ -53,35 +54,35 @@ class Response:
             body['data'] = data
         return APIResponse(body, code)
 
-    def ok(self, messages=None, data=None):
-        return self.build_message(200, 'OK', messages, data)
+    def ok(self, *, messages: Union[str, List[str]] = None, data=None):
+        return self._build_message(200, 'OK', messages, data)
 
-    def created(self, messages=None, data=None):
-        return self.build_message(201, 'CREATED', messages, data)
+    def created(self, *, messages: Union[str, List[str]] = None, data=None):
+        return self._build_message(201, 'CREATED', messages, data)
 
-    def bad_request(self, messages=None, data=None):
-        return self.build_message(400, 'BAD REQUEST', messages, data)
+    def bad_request(self, *, messages: Union[str, List[str]] = None, data=None):
+        return self._build_message(400, 'BAD REQUEST', messages, data)
 
-    def unauthorized(self, messages=None, data=None):
-        return self.build_message(401, 'UNAUTHORIZED', messages, data)
+    def unauthorized(self, *, messages: Union[str, List[str]] = None, data=None):
+        return self._build_message(401, 'UNAUTHORIZED', messages, data)
 
-    def forbidden(self, messages=None, data=None):
-        return self.build_message(403, 'FORBIDDEN', messages, data)
+    def forbidden(self, *, messages: Union[str, List[str]] = None, data=None):
+        return self._build_message(403, 'FORBIDDEN', messages, data)
 
-    def not_found(self, messages=None, data=None):
-        return self.build_message(404, 'NOT FOUND', messages, data)
+    def not_found(self, *, messages: Union[str, List[str]] = None, data=None):
+        return self._build_message(404, 'NOT FOUND', messages, data)
 
-    def method_not_allowed(self, messages=None, data=None):
-        return self.build_message(405, 'METHOD NOT ALLOWED', messages, data)
+    def method_not_allowed(self, *, messages: Union[str, List[str]] = None, data=None):
+        return self._build_message(405, 'METHOD NOT ALLOWED', messages, data)
 
-    def conflict(self, messages=None, data=None):
-        return self.build_message(409, 'CONFLICT', messages, data)
+    def conflict(self, *, messages: Union[str, List[str]] = None, data=None):
+        return self._build_message(409, 'CONFLICT', messages, data)
 
-    def unprocessable_entity(self, messages=None, data=None):
-        return self.build_message(422, 'UNPROCESSABLE ENTITY', messages, data)
+    def unprocessable_entity(self, *, messages: Union[str, List[str]] = None, data=None):
+        return self._build_message(422, 'UNPROCESSABLE ENTITY', messages, data)
 
-    def internal_server_error(self, messages=None, data=None):
-        return self.build_message(500, 'INTERNAL SERVER ERROR', messages, data)
+    def internal_server_error(self, *, messages: Union[str, List[str]] = None, data=None):
+        return self._build_message(500, 'INTERNAL SERVER ERROR', messages, data)
 
     def render_template(self, name: PathLike, params: dict = None, workdir: PathLike = None):
         if workdir is None:
@@ -94,7 +95,7 @@ class Response:
         try:
             content = files.render_template(workdir, name, params)
         except TemplateNotFound:
-            error_404_wd = self.context.internal_path('_files', 'templates')
+            error_404_wd = self.context.internal_files_path('templates')
             error_404 = paths.join('errors', '404.html.jinja2')
             content = files.render_template(error_404_wd, error_404, params)
         return AioResponse(body=content, status=200, content_type='text/html')
@@ -108,4 +109,4 @@ class Response:
             exception = exception.errors[0]
         for except_cls in self._exceptions:
             if isinstance(exception, except_cls):
-                return self._exceptions[except_cls](messages)
+                return self._exceptions[except_cls](messages=messages)
